[−][src]Enum pulsectl::controllers::types::DevState
This is a wrapper around SinkState and SourceState as they have the same values
Variants
This state is used when the server does not support sink state introspection.
Running, sink is playing and used by at least one non-corked sink-input.
When idle, the sink is playing but there is no non-corked sink-input attached to it.
When suspended, actual sink access can be closed, for instance.