[−][src]Struct pulsectl::controllers::types::ApplicationInfo
Fields
index: u32Index of the sink input.
name: Option<String>Name of the sink input.
owner_module: Option<u32>Index of the module this sink input belongs to, or None when it does not belong to any
module.
client: Option<u32>Index of the client this sink input belongs to, or invalid when it does not belong to any client.
connection_id: u32Index of the connected sink/source.
sample_spec: SpecThe sample specification of the sink input.
channel_map: MapChannel map.
volume: ChannelVolumesThe volume of this sink input.
buffer_usec: MicroSecondsLatency due to buffering in sink input, see
def::TimingInfo for details.
connection_usec: MicroSecondsLatency of the sink device, see
def::TimingInfo for details.
resample_method: Option<String>The resampling method used by this sink input.
driver: Option<String>Driver name.
mute: boolStream muted.
proplist: ProplistProperty list.
corked: boolStream corked.
has_volume: boolStream has volume. If not set, then the meaning of this struct’s volume member is unspecified.
volume_writable: boolThe volume can be set. If not set, the volume can still change even though clients can’t control the volume.
format: InfoStream format information.