[][src]Struct pulsectl::controllers::types::DeviceInfo

pub struct DeviceInfo {
    pub index: u32,
    pub name: Option<String>,
    pub description: Option<String>,
    pub sample_spec: Spec,
    pub channel_map: Map,
    pub owner_module: Option<u32>,
    pub volume: ChannelVolumes,
    pub mute: bool,
    pub monitor: Option<u32>,
    pub monitor_name: Option<String>,
    pub latency: MicroSeconds,
    pub driver: Option<String>,
    pub flags: SinkFlagSet,
    pub proplist: Proplist,
    pub configured_latency: MicroSeconds,
    pub base_volume: Volume,
    pub state: DevState,
    pub n_volume_steps: u32,
    pub card: Option<u32>,
    pub ports: Vec<DevicePortInfo>,
    pub active_port: Option<DevicePortInfo>,
    pub formats: Vec<Info>,
}

Fields

index: u32

Index of the sink.

name: Option<String>

Name of the sink.

description: Option<String>

Description of this sink.

sample_spec: Spec

Sample spec of this sink.

channel_map: Map

Channel map.

owner_module: Option<u32>

Index of the owning module of this sink, or None if is invalid.

volume: ChannelVolumes

Volume of the sink.

mute: bool

Mute switch of the sink.

monitor: Option<u32>

Index of the monitor source connected to this sink.

monitor_name: Option<String>

The name of the monitor source.

latency: MicroSeconds

Length of queued audio in the output buffer.

driver: Option<String>

Driver name.

flags: SinkFlagSet

Flags.

proplist: Proplist

Property list.

configured_latency: MicroSeconds

The latency this device has been configured to.

base_volume: Volume

Some kind of “base” volume that refers to unamplified/unattenuated volume in the context of the output device.

state: DevState

State.

n_volume_steps: u32

Number of volume steps for sinks which do not support arbitrary volumes.

card: Option<u32>

Card index, or None if invalid.

ports: Vec<DevicePortInfo>

Set of available ports.

active_port: Option<DevicePortInfo>formats: Vec<Info>

Set of formats supported by the sink.