[][src]Struct pulsectl::controllers::types::DevicePortInfo

pub struct DevicePortInfo {
    pub name: Option<String>,
    pub description: Option<String>,
    pub priority: u32,
    pub available: PortAvailable,
}

These structs are direct representations of what libpulse_binding gives created to be copyable / cloneable for use in and out of callbacks This is a wrapper around SinkPortInfo and SourcePortInfo as they have the same members

Fields

name: Option<String>

Name of the sink.

description: Option<String>

Description of this sink.

priority: u32

The higher this value is, the more useful this port is as a default.

available: PortAvailable

A flag indicating availability status of this port.