[][src]Struct pulsectl::controllers::types::ApplicationInfo

pub struct ApplicationInfo {
    pub index: u32,
    pub name: Option<String>,
    pub owner_module: Option<u32>,
    pub client: Option<u32>,
    pub connection_id: u32,
    pub sample_spec: Spec,
    pub channel_map: Map,
    pub volume: ChannelVolumes,
    pub buffer_usec: MicroSeconds,
    pub connection_usec: MicroSeconds,
    pub resample_method: Option<String>,
    pub driver: Option<String>,
    pub mute: bool,
    pub proplist: Proplist,
    pub corked: bool,
    pub has_volume: bool,
    pub volume_writable: bool,
    pub format: Info,
}

Fields

index: u32

Index of the sink input.

name: Option<String>

Name of the sink input.

owner_module: Option<u32>

Index of the module this sink input belongs to, or None when it does not belong to any module.

client: Option<u32>

Index of the client this sink input belongs to, or invalid when it does not belong to any client.

connection_id: u32

Index of the connected sink/source.

sample_spec: Spec

The sample specification of the sink input.

channel_map: Map

Channel map.

volume: ChannelVolumes

The volume of this sink input.

buffer_usec: MicroSeconds

Latency due to buffering in sink input, see def::TimingInfo for details.

connection_usec: MicroSeconds

Latency of the sink device, see def::TimingInfo for details.

resample_method: Option<String>

The resampling method used by this sink input.

driver: Option<String>

Driver name.

mute: bool

Stream muted.

proplist: Proplist

Property list.

corked: bool

Stream corked.

has_volume: bool

Stream has volume. If not set, then the meaning of this struct’s volume member is unspecified.

volume_writable: bool

The volume can be set. If not set, the volume can still change even though clients can’t control the volume.

format: Info

Stream format information.