[−][src]Struct pulsectl::controllers::types::DeviceInfo
Fields
index: u32Index of the sink.
name: Option<String>Name of the sink.
description: Option<String>Description of this sink.
sample_spec: SpecSample spec of this sink.
channel_map: MapChannel map.
owner_module: Option<u32>Index of the owning module of this sink, or None if is invalid.
volume: ChannelVolumesVolume of the sink.
mute: boolMute switch of the sink.
monitor: Option<u32>Index of the monitor source connected to this sink.
monitor_name: Option<String>The name of the monitor source.
latency: MicroSecondsLength of queued audio in the output buffer.
driver: Option<String>Driver name.
flags: SinkFlagSetFlags.
proplist: ProplistProperty list.
configured_latency: MicroSecondsThe latency this device has been configured to.
base_volume: VolumeSome kind of “base” volume that refers to unamplified/unattenuated volume in the context of the output device.
state: DevStateState.
n_volume_steps: u32Number of volume steps for sinks which do not support arbitrary volumes.
card: Option<u32>Card index, or None if invalid.
ports: Vec<DevicePortInfo>Set of available ports.
active_port: Option<DevicePortInfo>formats: Vec<Info>Set of formats supported by the sink.